#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(lme4)
library(lmerTest)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d2_survey = read.csv("study2_survey_by_participant.csv")
d2_all = read.csv("study2_survey_by_group.csv")
wc = read.csv("LIWC_data.csv")
observer = read.csv("sound_video_codes.csv")
d2_gen = read.csv("study2_data.csv")
d1_gen = read.csv("study1_data.csv")
d2_gen = d2_gen %>% dplyr::select(-ontime) %>% mutate(study = 2)
d1_gen = d1_gen %>% mutate(study = 1)

d_all = rbind(d1_gen, d2_gen)

#########################################################
# Self-Perceptions of Dominance                         #
#########################################################

####### means by condition #######   

d2_survey %>% 
  group_by(cond) %>%
  summarise(mean = mean(dominant, na.rm=T),
            sd = sd(dominant, na.rm=T))

####### regressions ####### 

summary(lmer(dominant ~ cond + (1|Group.Number), data = d2_survey))
summary(glm.nb(creative_count ~ dominant, data = d2_all))
summary(glm.nb(creative_count ~ cond + dominant, data = d2_all))

#########################################################
# Asymmetry in Self-Perceptions of Dominance            #
#########################################################

########## calculation ########### 
subj_dom = d2_survey %>% dplyr::select(Group.Number, writer, dominant, cond) %>%
  spread(writer, dominant) %>%
  mutate(subj_dom = (abs(w-nw)/(w+nw)))

####### means by condition #######   
subj_dom %>% 
  group_by(cond) %>%
  summarise(mean = mean(subj_dom, na.rm=T),
            sd = sd(subj_dom, na.rm=T))

####### regressions ####### 

# does condition affect dominance?
summary(lm(subj_dom ~ cond, data = subj_dom))

# does dominance affect creativity?
subj_dom_all = merge(d2_gen, subj_dom, by = c("Group.Number", "cond"))
summary(glm.nb(creative_count ~ subj_dom, data = subj_dom_all))

#effect of condition while controlling for dominance 
summary(glm.nb(creative_count ~ subj_dom + cond, data = subj_dom_all))

#########################################################
# Verbal Dominance                                      #
#########################################################

########## calculation ########### 

wc = wc %>% dplyr::select(Group.Number, participant, WC, cond) %>%
  spread(participant, WC) %>%
  rename(wc_1 = nonwriter,
         wc_2 = writer) %>%
  mutate(dom = (abs(wc_1-wc_2)/(wc_1+wc_2))) %>%
  mutate(study = case_when(
    grepl("study2",Group.Number) ~ 2,
    !grepl("study2",Group.Number) ~ 1
  ))

#lower numbers, more egalitarian

####### means by condition #######   
wc %>% 
  group_by(cond) %>%
  summarise(mean = mean(dom, na.rm=T),
            sd = sd(dom, na.rm=T))

####### regressions ####### 

# does condition affect dominance?
summary(lm(dom ~ cond, data = wc))

# does dominance affect creativity?
wc = wc %>% mutate(Group.Number = gsub("study2", "", Group.Number))
wc_all = merge(d_all, wc, by = c("Group.Number", "study","cond"))
summary(glm.nb(creative_count ~ dom, data = wc_all))

#effect of condition while controlling for dominance 
summary(glm.nb(creative_count ~ dom + cond, data = wc_all))

#########################################################
#  Observer-Rated Dominance                             #
#########################################################

####### means by condition #######   
observer %>% 
  group_by(cond) %>%
  summarise(mean = mean(dominant_sound, na.rm=T),
            sd = sd(dominant_sound, na.rm=T))

####### regressions ####### 

# does condition affect dominance?
summary(lmer(dominant_sound ~ cond +(1|Group.Number) + (1|id), data = observer))

# does dominance affect creativity?
observer_mean = observer %>% dplyr::select(-id) %>%
  group_by(Group.Number, video) %>%
  summarise(dominant_sound = mean(dominant_sound)) %>%
  dplyr::select(-video) %>%
  group_by(Group.Number) %>%
  summarise(dominant_sound = mean(dominant_sound))

observer_all = merge(d2_gen, observer_mean, by = "Group.Number")

summary(glm.nb(creative_count ~ dominant_sound, data = observer_all))

#effect of condition while controlling for dominance 
summary(glm.nb(creative_count ~ dominant_sound + cond, data = observer_all))

#########################################################
# test for normality                                    #
#########################################################

hist(d2_survey$dominant)
hist(subj_dom$subj_dom) #assym
hist(wc$dom) #verbal
hist(observer$dominant_sound) 

shapiro.test(d2_survey$dominant)
shapiro.test(subj_dom$subj_dom)
shapiro.test(wc$dom)
shapiro.test(observer$dominant_sound)

#########################################################
# test for homogeneity of variance                      #
#########################################################

leveneTest(dom ~ cond, data = wc)
leveneTest(dominant_sound ~ cond, data = observer)
leveneTest(dominant ~ cond, data = d2_survey)
leveneTest(subj_dom ~ cond, data = subj_dom)

### non-parametric tests ###
kruskal.test(dom ~ cond, data = wc_all)
kruskal.test(dominant_sound ~ cond, data = observer_all)
kruskal.test(dominant ~ cond, data = d2_all)
kruskal.test(subj_dom ~ cond, data = subj_dom)

#########################################################
# Effect Sizes                                          #
#########################################################

observer$cond = as.factor(observer$cond)
d2_survey$cond = as.factor(d2_survey$cond)

cohen.d(d2_survey$dominant, d2_survey$cond)
d.noNA = subj_dom %>% filter(!is.na(subj_dom))
cohen.d(d.noNA$subj_dom, d.noNA$cond)
cohen.d(wc$dom, wc$cond)
cohen.d(observer$dominant_sound, observer$cond)
