#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(ggplot2)
library(dplyr)
library(tidyr)
library(MASS)
library(lmerTest)

#move data folder to desktop
setwd("~/Desktop/Data")

d_gen = read.csv("field_generation_data.csv")
d_scored = read.csv("field_scored_data.csv")

d_gen$session = as.factor(d_gen$session)
d_scored$session = as.factor(d_scored$session)

#########################################################
# means by condition                                    #
#########################################################

table(d_gen$cond) #sample size per condition
table(d_scored$cond)
table(d_gen$country)

d_gen %>% 
  group_by(cond) %>%
  summarise(mean = mean(idea_number, na.rm=T),
            sd = sd(idea_number, na.rm=T))

d_gen %>% 
  group_by(cond,country) %>%
  summarise(mean = mean(idea_number, na.rm=T),
            sd = sd(idea_number, na.rm=T))

d_scored %>%
  gather(key, value, -Group.Number, -cond, -session, -country, -notes) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

table1 =
  d_scored %>%
  gather(key, value, -Group.Number, -cond, -session, -country, -notes) %>%
  group_by(key, country, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

table2 =
  d_gen %>%
  gather(key, value, -Group.Number, -cond, -session, -country) %>%
  group_by(key, country, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

#########################################################
# regressions                                           #
#########################################################

### main analysis: idea generation ###

summary(glmer.nb(idea_number ~ cond + country + (1|session), data=d_gen))

### main analysis: idea generation for scored ideas ###

summary(glmer.nb(idea_number ~ cond + country + (1|session), data=d_scored))
summary(glmer.nb(creative_count ~ cond + country + (1|session), data=d_scored))

### main analysis: idea selection for scored ideas ###

summary(lmer(top_creative ~ cond + country + (1|session), data=d_scored))
summary(lmer(p_select_score ~ cond + country + (1|session), data=d_scored))
summary(lmer(diff ~ cond + country + (1|session), data=d_scored))
kruskal.test(diff ~ cond, data = d_scored)

#######################################################
# controls & checks                                   #
#######################################################

#controlling for idea number
summary(lmer(diff ~ cond + country + idea_number + (1|session), data=d_scored))
summary(lmer(p_select_creative ~ cond + country + idea_number + top_creative + (1|session), data=d_scored))

#checking other measures of idea quality
summary(lmer(avg_creative ~ cond + country + (1|session), data=d_scored))
summary(lmer(var_creative ~ cond + country + (1|session), data=d_scored))

#robustness check: linear regressions
summary(lmer(idea_number ~ cond + country + (1|session), data=d_gen))
summary(lmer(idea_number ~ cond + country + (1|session), data=d_scored))
summary(lmer(creative_count ~ cond + country + (1|session), data=d_scored))

#######################################################
# effect sizes                                        #
#######################################################
d_scored$cond = as.factor(d_scored$cond)
d_gen$cond = as.factor(d_gen$cond)

cohen.d(d_gen$idea_number, d_gen$cond)
cohen.d(d_scored$idea_number, d_scored$cond)
cohen.d(d_scored$creative_count, d_scored$cond)
cohen.d(d_scored$top_creative, d_scored$cond)
cohen.d(d_scored$avg_creative, d_scored$cond)

#9 groups only have one idea
#removing these NAs for effect size calculation
d.noNA = d_scored %>% filter(!is.na(var_creative))
cohen.d(d.noNA$var_creative, d.noNA$cond)

#28 groups missing/dropped for various reasons (see notes variable)
#removing these NAs for effect size calculation
d_scored$cond = as.factor(d_scored$cond)
d.noNA = d_scored %>% filter(!is.na(diff))
d.noNA = d_scored %>% filter(!is.na(p_select_score))
cohen.d(d.noNA$diff, d.noNA$cond)
cohen.d(d.noNA$p_select_score, d.noNA$cond)

#removing these NAs for effect size calculation
d.noNA = d_scored %>% filter(!is.na(top_creative))
cohen.d(d.noNA$top_creative, d.noNA$cond)

d.noNA = d_scored %>% filter(!is.na(avg_creative))

#######################################################
# power analysis                                      #
#######################################################
library(PASSED)

power_NegativeBinomial(n1 = 365, n2 = 380, mu1 = 8.58, mu2 = 7.43, theta = 3.75)

#######################################################
# equivalence test for average creativity             #
#######################################################

d_scored %>%
  dplyr::select(cond, avg_creative) %>%
  group_by(cond) %>%
  summarise(mean = mean(avg_creative, na.rm=T),
            sd = sd(avg_creative, na.rm=T))

table(d_scored$cond)

library("TOSTER")
TOSTtwo.raw(m1=2.99,m2=2.98,sd1=0.382,sd2=0.399,n1=305,n2=317,low_eqbound=-0.08, high_eqbound=0.08, alpha = 0.05, var.equal=TRUE)
