#!/usr/bin/env python
"""idea path generation"""

import random
from statistics import mean
import argparse
import json
import collections
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.backends.backend_pdf as backend_pdf
import lsa_helper


def remove_zeros(_list):
    """
    remove whatever zeros in the trailing place
    """
    for idx, i in enumerate(reversed(_list)):
        if i:
            if idx == 0:
                _list = _list
            else:
                _list = _list[:-1*idx]
            break
    return _list


def get_idea_column_names():
    """
    get idea column names
    """
    return [CONFIG["column_name"]+str(idx) for idx in range(1, CONFIG["questions_in_the_study"]+1)]


def user_input(seed_word):
    """
    provide a portal to grab user input
    """
    print("Please input words based on the seed word: ", seed_word)
    print("Enter \'***exit***\' to exit")
    anwer_list = [seed_word]
    input_flag = True
    while input_flag:
        input_sentence = input("Enter word : ")
        if input_sentence == '***exit***':
            input_flag = False
        else:
            anwer_list.append(input_sentence)
    return  anwer_list


def sample_usage(seed_word=None):
    """
    provide a sample usage for the user
    """
    sample_seed_words = ["fire", "coffee", "house", "toast", "tree"]
    if seed_word is None:
        seed_word = sample_seed_words[random.randint(0, 4)]
    answer_list = user_input(seed_word)

    LSA_INSTANCE.construct_lsa_model()

    seed_word, answer_list, flow_list = LSA_INSTANCE.get_forward_flow(seed_word, answer_list)

    answer_list, flow_list = LSA_INSTANCE.get_valid_flow(answer_list, flow_list)
    plt.plot(answer_list, flow_list)
    plt.ylabel('flow value')
    title_text = "average score "+str(sum(flow_list)/len(flow_list))
    plt.title(title_text)
    plt.show()


def merge_file(file_1, file_2):
    """
    merge two input file, getting a file for us to work on afterwards
    """
    df_response = pd.read_csv(file_1)
    df_metadata = pd.read_csv(file_2)

    new_data = []
    for idx, row in df_metadata.iterrows():
        # remove all test response
        if str(row["PID"]) in ["0", "11111", "22222"]:
            continue

        sub_df = df_response.loc[(df_response['PID'] == str(row["PID"]))
                                & (df_response['V6'] == row["IPAddress"])]
        if sub_df.shape[0] != 1:
            continue

        # preprare for the value for each column
        data_row = []
        data_row.append(row["PID"])
        data_row.extend(sub_df.iloc[0, 50:90].values.tolist())
        data_row.append(row["IPAddress"])
        data_row.append(sub_df.iloc[0, 11])
        data_row.append(row["English Fluency"])

        new_data.append(data_row)

    column_names = ["PID"]
    column_names.extend(get_idea_column_names())
    column_names.extend(["IPAddress", "cond_main", "cond_mod"])

    df_merged = pd.DataFrame(new_data)
    df_merged.columns = column_names
    df_merged.to_csv(CONFIG["data_path"], index=False)





def find_common_words():
    '''
    output common word file based on dataset statistics
    '''

    word_list = []
    number_of_answers = 0

    _df = pd.read_csv(CONFIG["data_path"])

    for _, row in _df.iterrows():
        answer_list = [x for x in row[get_idea_column_names()] if str(x) != 'nan']
        for answer in answer_list:
            answer_word_list = LSA_INSTANCE.remove_symbols(answer).split()
            if len(answer_word_list) != 0:
                number_of_answers += 1
            word_list.extend(answer_word_list)

    ctr = collections.Counter(word_list)

    word_list = []
    count_list = []
    for key, value in ctr.items():
        word_list.append(key)
        count_list.append(value)

    try:
        file = open(CONFIG["common_word_file_path"], "w", encoding='utf-8')
        for idx, count in enumerate(count_list):
            if count/number_of_answers >= CONFIG["max_appearance_ratio"]:
                file.write(word_list[idx] + '\n')
        file.close()
    except Exception as e:
        print("please provide the common word file path in config.json")
        return




def get_detail_score():
    """
    generate detail score: each participant's score for each answer

    """

    # read the raw data - participants' response
    _df = pd.read_csv(CONFIG["data_path"], encoding='Latin-1')
    try:
        if CONFIG["remove_common_words"]==1:
            for idx, row in _df.iterrows():
                for column_name in get_idea_column_names():
                    if str(row[column_name]) != 'nan':
                        new_answer = LSA_INSTANCE.remove_common_words(row[column_name])
                        _df.loc[idx, column_name] = new_answer
        _df.to_csv(CONFIG["data_path"][:-4]+"_cleaned.csv", index=False)
        print("removed common words")
    except Exception as e:
        print("get_detail_score: ", e)

    print(_df.shape)

    # the data we need to capture: PID, cond_main, cond_mod, avg score, flow value
    column_names = ["PID"]
    column_names.extend(["cond_main", "cond_mod"])
    column_names.append("average score (per participant)")

    idea_columns_names = get_idea_column_names()
    if CONFIG["first_word_as_seed_word"] == 1: 
        if len(idea_columns_names)>0:
            idea_columns_names = idea_columns_names[1:]
    column_names.extend(idea_columns_names)

    # loop through each participant's response, calculate the flow
    result = []
    for idx, row in _df.iterrows():
        print(idx)

        # prepare the word list - user's response
        answer_list = [CONFIG["seed_word"]]
        answer_list.extend(row[get_idea_column_names()])
        answer_list = [x for x in answer_list if str(x) != 'nan']

        if CONFIG["first_word_as_seed_word"] == 1:
            if len(answer_list)>0:
                CONFIG["seed_word"] = answer_list[0]
                answer_list = answer_list[1:]

        # calcualte the flow - based on the seed word and the response user provides
        _, answer_list, flow_list = LSA_INSTANCE.get_forward_flow(CONFIG["seed_word"], answer_list)
        answer_list, flow_list = LSA_INSTANCE.get_valid_flow(answer_list, flow_list, fill_zero=True)



        # the following code preprare for the value for each column

        # "PID" : participant number
        # "cond_main", "cond_mod": Experiment condition
        # "average score" : Add the mean flow
        entry = [row[0]]
        entry.extend([row["cond_main"], row["cond_mod"]])
        try:
            entry.append(mean(flow_list[1:]))
        except Exception as error:
            entry.append(0)
            print(f"at position {idx}, there is an error: {error}")

        # Add the forward flow value
        entry.extend(flow_list[1:])



        # add this record to the final dataframe
        result.append(entry)


    # create dataframe, and output result to a csv file
    new_df = pd.DataFrame(result)
    new_df.columns = column_names
    new_df.to_csv(CONFIG["score_path"], index=False)

    # output the correction we used
    LSA_INSTANCE.output_correction_dict()


def plot_graph(args, plot_data):
    """
    plot graph with 3 lines: average line, line with variable 1, line with variable 2
    """
    flow_0, label_0, flow_1, label_1, flow_2, label_2, pdf_name = plot_data
    flow_0 = remove_zeros(flow_0)
    flow_1 = remove_zeros(flow_1)
    flow_2 = remove_zeros(flow_2)
    fig, _ = plt.subplots()

    if not args.by_questions:
        plt.plot([(i-1)/len(flow_0) for i in range(1, len(flow_0)+1)], flow_0, label=label_0)
        plt.plot([(i-1)/len(flow_1) for i in range(1, len(flow_1)+1)], flow_1, label=label_1)
        plt.plot([(i-1)/len(flow_2) for i in range(1, len(flow_2)+1)], flow_2, label=label_2)
        pdf_name = pdf_name+"_byscale_"+str(args.num_questions)
    else:
        print(len(flow_1))
        print(len(flow_2))
        plt.plot(range(1, len(flow_0)+1), flow_0, label=label_0)
        plt.plot(range(1, len(flow_1)+1), flow_1, label=label_1)
        plt.plot(range(1, len(flow_2)+1), flow_2, label=label_2)
        pdf_name = pdf_name+"_byquestions_"+str(args.num_questions)

    plt.ylabel('flow value')
    plt.legend(loc="upper left")
    pdf = backend_pdf.PdfPages(pdf_name+".pdf")
    pdf.savefig(fig, dpi=100)
    pdf.close()




def filter_data_for_analysis(args, _df, pdf_name, label):
    """
    we may want to control the condition value to see the effect
    this function filter the data based on user's request

    args.keep_cond_main == 0 : keep all the data with cond_main == 0
    args.keep_cond_main == 1 : keep all the data with cond_main == 1
    args.keep_cond_mod == 0 : keep all the data with cond_mod == 0
    args.keep_cond_mod == 1 : keep all the data with cond_mod == 1


    This is helpful in some scenario:
    applying cond_mod may have greater effect on groups with "cond_main = 0" than "cond_main = 1"
    """


    # Base on what value of cond_main we wnat to keep - prepare data, labels, file name
    if args.keep_cond_main == 0:
        _df = _df.loc[_df["cond_main"] == CONFIG["cond_main_0"]]
        pdf_name += CONFIG["cond_main_0_label"] + " - "
        label = CONFIG["cond_main_0_label"] + " - "
    elif args.keep_cond_main == 1:
        _df = _df.loc[_df["cond_main"] == CONFIG["cond_main_1"]]
        pdf_name += CONFIG["cond_main_1_label"] + " - "
        label = CONFIG["cond_main_1_label"] + " - "
    else:
        # do nothing, because user didn't want to filter any value
        pass

    # Base on what value of cond_mod we wnat to keep - prepare data, labels, file name
    if args.keep_cond_mod == 0:
        _df = _df.loc[_df["cond_mod"] == CONFIG["cond_mod_0"]]
        pdf_name += CONFIG["cond_mod_0_label"] + " - "
        label = CONFIG["cond_mod_0_label"] + " - "
    elif args.keep_cond_mod == 1:
        _df = _df.loc[_df["cond_mod"] == CONFIG["cond_mod_1"]]
        pdf_name += CONFIG["cond_mod_1_label"] + " - "
        label = CONFIG["cond_mod_1_label"] + " - "
    else:
        # do nothing, because user didn't want to filter any value
        pass

    return _df, pdf_name, label


def plot_dataset_histogram(_df, pdf_name):
    '''
    plot histogram of flow value
    '''

    # compute the histogram of hte distribution
    if CONFIG["hist"]:
        fig, _ = plt.subplots()

        individual_scores = []
        for idx in range(0, _df.shape[0]):
            average_flow = LSA_INSTANCE.get_question_avg_flow(_df.loc[idx:idx, :], 4)
            score = 0
            try:
                score = mean(average_flow)
            except Exception as error:
                print("error in plotting historgram: ", error)
                score = 0

            individual_scores.append(score)
        plt.hist(individual_scores, density=True)
        pdf = backend_pdf.PdfPages(pdf_name+"_individual_scores"+".pdf")
        pdf.savefig(fig, dpi=100)
        pdf.close()


def analyze_file(args):
    """
    analyze file base on the args
    """

    # read the forward flow score
    _df = pd.read_csv(CONFIG["score_path"])
    pdf_name = CONFIG["pdf_path"]
    label = ""


    _df, pdf_name, label = filter_data_for_analysis(args, _df, pdf_name, label)


    # if we want to study the effect of cond_main
    if args.cond_main:
        # average
        flow_0 = LSA_INSTANCE.get_question_avg_flow(_df, 4)[:args.num_questions]
        label_0 = label+"average"

        # Case 1: cond_main value = cond_main_0
        tmp = _df.loc[_df["cond_main"] == CONFIG["cond_main_0"]]
        flow_1 = LSA_INSTANCE.get_question_avg_flow(tmp, 4)[:args.num_questions]
        label_1 = label + CONFIG["cond_main_0_label"]

        # Case 2: cond_main value = cond_main_0
        tmp = _df.loc[_df["cond_main"] == CONFIG["cond_main_1"]]
        flow_2 = LSA_INSTANCE.get_question_avg_flow(tmp, 4)[:args.num_questions]
        label_2 = label + CONFIG["cond_main_1_label"]

        pdf_name += CONFIG["cond_main_0_label"]+"_vs_"+CONFIG["cond_main_1_label"]
        plot_graph(args, [flow_0, label_0, flow_1, label_1, flow_2, label_2, pdf_name])

    # if we want to study the effect of cond_mod
    if args.cond_mod:
        # average
        flow_0 = LSA_INSTANCE.get_question_avg_flow(_df, 4)[:args.num_questions]
        label_0 = label+"average"

        # Case 1: cond_mod value = cond_mod_0
        tmp = _df.loc[_df["cond_mod"] == CONFIG["cond_mod_0"]]
        flow_1 = LSA_INSTANCE.get_question_avg_flow(tmp, 4)[:args.num_questions]
        label_1 = label + CONFIG["cond_mod_0_label"]

        # Case 2: cond_mod value = cond_mod_0
        tmp = _df.loc[_df["cond_mod"] == CONFIG["cond_mod_1"]]
        flow_2 = LSA_INSTANCE.get_question_avg_flow(tmp, 4)[:args.num_questions]
        label_2 = label + CONFIG["cond_mod_1_label"]

        pdf_name += CONFIG["cond_mod_0_label"]+"_vs_"+CONFIG["cond_mod_1_label"]
        plot_graph(args, [flow_0, label_0, flow_1, label_1, flow_2, label_2, pdf_name])

    plot_dataset_histogram(_df, pdf_name)

    print("graph plotted")


def get_arg_parser():
    """
    Parse the input arguments
    help to decide what task should the code perform

    """

    parser = argparse.ArgumentParser()

    parser.add_argument(
        "--trail", 
        help="start a pilot test",
        action="store_true")
    parser.add_argument(
        "--seed",
        type=str,
        required=False,
        help="start a pilot test")

    parser.add_argument(
        "--display",
        help="interactive interface for looking participant's result",
        action="store_true")

    parser.add_argument(
        "--analyze",
        help="compute result and save files and graphs",
        action="store_true")

    parser.add_argument(
        "--find_common_words",
        help="find the most commonly appeared words in the dataset",
        action="store_true")

    parser.add_argument(
        "--compute",
        help="compute result and save files and graphs",
        action="store_true")

    parser.add_argument(
        "--merge",
        help="merge files",
        action="store_true")


    parser.add_argument(
        "--num_questions",
        type=int,
        required=False,
        default=CONFIG["default_number"],
        help="How many questions needs to be studied")

    parser.add_argument(
        "--cond_main",
        help="whether group data by main condition",
        action="store_true")
    parser.add_argument(
        "--cond_mod",
        help="whether group data by mod condition",
        action="store_true")

    parser.add_argument(
        "--keep_cond_main",
        type=int,
        required=False,
        help="choose what condition main value to keep")
    parser.add_argument(
        "--keep_cond_mod",
        type=int,
        required=False,
        help="choose what condition mod value to keep")


    parser.add_argument(
        "--make_correction",
        type=int,
        required=False,
        default=CONFIG["make_correction"],
        help="whether to perform correction")
    parser.add_argument(
        "--use_correction_file",
        type=int,
        required=False,
        default=CONFIG["use_correction_file"],
        help="whether to correct with existing file")



    parser.add_argument(
        "--by_questions",
        help="if not set, then we will scale the x-axis",
        action="store_true")


    return parser


def main(args):
    """
    Handling the parse passed in

    """

    if args.make_correction == 1:
        CONFIG["make_correction"] = 1
    else:
        CONFIG["make_correction"] = 0

    if args.use_correction_file == 1:
        CONFIG["use_correction_file"] = 1
    else:
        CONFIG["use_correction_file"] = 0

    # add configuration to the lsa instance
    LSA_INSTANCE.assign_config(CONFIG)


    if args.trail:
        if args.seed:
            sample_usage(args.seed)
        else:
            sample_usage()
    elif args.merge:
        merge_file("./data/sample.csv", "./data/input.csv")
    elif args.find_common_words:
        find_common_words()
    elif args.compute:
        LSA_INSTANCE.construct_lsa_model()
        get_detail_score()
    elif args.analyze:
        # LSA_INSTANCE.construct_lsa_model()
        analyze_file(args)
    elif args.display:
        pass
        # display commandline


# configuration file
CONFIG = {}

# latent semantic analysis instance
LSA_INSTANCE = lsa_helper.LSA_HELPER()

if __name__ == "__main__":
    # read the configuration file
    CONFIG = json.load(open("./config/config.json", "r"))

    # read user command (the parameter provided to the user)
    PARSER = get_arg_parser()
    ARGS = PARSER.parse_args()

    # decide the functionality to perform in this program
    main(ARGS)
