#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(tidyr)
library(effsize)
library(MASS)

#move data folder to desktop
setwd("~/Desktop/Data")

d1 = read.csv("study1_data.csv")
d2 = read.csv("study2_data.csv")

#########################################################
# merge two datasets                                    #
#########################################################

d1 = d1 %>% dplyr::select(Group.Number, cond, idea_number, creative_count, diff, p_select_creative, top_creative, avg_creative) %>%
  mutate(study = "1")
d2 = d2 %>% dplyr::select(Group.Number, cond, idea_number, creative_count, diff, p_select_creative, top_creative, avg_creative) %>%
  mutate(study = "2")

d = rbind(d1, d2)

#########################################################
# means by condition                                    #
#########################################################

table(d$cond) #sample size per condition

table = d %>%
  gather(key, value, -Group.Number, -cond, -study) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm=T),
            sd = sd(value, na.rm=T))

#########################################################
# regressions                                           #
#########################################################

### main analysis: idea generation ###

summary(glm.nb(idea_number ~ cond, data = d))
summary(glm.nb(creative_count ~ cond, data = d))

#controlling for study

summary(glm.nb(idea_number ~ cond + study, data = d))
summary(glm.nb(creative_count ~ cond + study, data = d))

### main analysis: idea selection ###

summary(lm(p_select_creative ~ cond, data=d))
summary(lm(diff ~ cond, data=d))

#controlling for study
summary(lm(diff ~ cond + study, data=d))
summary(lm(p_select_creative ~ cond + study, data=d))

#######################################################
# controls & checks                                   #
#######################################################

#controlling for idea number
summary(lm(diff ~ cond + idea_number, data=d))
summary(lm(p_select_creative ~ cond + idea_number, data=d))
summary(lm(p_select_creative ~ cond + idea_number + top_creative, data=d))

#checking other measures of idea quality
summary(lm(top_creative ~ cond, data=d))
summary(lm(avg_creative ~ cond, data=d))
summary(lm(avg_top_creative ~ cond, data=d))
summary(lm(var_creative ~ cond, data=d))

#robustness check: linear regressions
summary(lm(creative_count ~ cond, data=d))
summary(lm(idea_number ~ cond, data=d))

#######################################################
# effect sizes                                        #
#######################################################

cohen.d(d$idea_number, d$cond)
cohen.d(d$creative_count, d$cond)
cohen.d(d$avg_creative, d$cond)
cohen.d(d$avg_top_creative, d$cond)
cohen.d(d$top_creative, d$cond)

#9 groups did not select their top idea
#removing these NAs for effect size calculation
d.noNA = d %>% filter(!is.na(diff))
cohen.d(d.noNA$diff, d.noNA$cond)
cohen.d(d.noNA$p_select_creative, d.noNA$cond)

#1 group only have one idea
#removing these NAs for effect size calculation
d.noNA = d %>% filter(!is.na(var_creative))
cohen.d(d.noNA$var_creative, d.noNA$cond)


#######################################################
# power analysis                                      #
#######################################################

library(PASSED)
power_NegativeBinomial(mu1 = 7.9, mu2 = 6.7, theta = 15.52, power=.8)

power_NegativeBinomial(n1 = 149, n2 = 152, mu1 = 7.9, mu2 = 6.7, theta = 15.52)


#######################################################
# equivalence test for average creativity             #
#######################################################

d %>%
  dplyr::select(cond, avg_creative) %>%
  group_by(cond) %>%
  summarise(mean = mean(avg_creative, na.rm=T),
            sd = sd(avg_creative, na.rm=T))


library("TOSTER")
TOSTtwo.raw(m1=3.95,m2=3.92,sd1=0.394,sd2=0.414,n1=149,n2=152,low_eqbound=-0.08, high_eqbound=0.08, alpha = 0.05, var.equal=TRUE)