#!/usr/bin/env python
"""latent segmantic analysis helper"""

from statistics import mean
import re
import numpy as np
from scipy.spatial.distance import cosine
import corrector


class LSA_HELPER():
    """
    helper for latent segmatic analysis
    """

    def __init__(self):
        self.LSA_DICT = {}
        self.CONFIG = {}
        self.corrector = corrector.corrector()
        self.common_word_list = []

    def assign_config(self, CONFIG):
        """
        assign value to the config field
        """
        self.CONFIG = CONFIG
        self.corrector.assign_config(self.CONFIG)
        try:
            if self.CONFIG["remove_common_words"] == 1:
                self.load_common_word_list()
        except Exception as e:
            pass

    def load_common_word_list(self):
        '''
        load the common word list specified in the configuration file
        '''

        self.common_word_list = []

        file = open(self.CONFIG["common_word_file_path"], "r", encoding='utf-8')
        for word in file:
            try:
                if word == "":
                    pass
                elif word[0] == "-":
                    pass
                else:
                    self.common_word_list.append(word[:-1])
            except Exception as e:
                print(e)
        file.close()

        # print(self.common_word_list)



    def construct_lsa_model(self, word_file_path='model/voc', vector_file_path='model/lsaModel'):
        """
        construct lsa model based on the input provided
        """
        self.LSA_DICT = {}
        word_file = open(word_file_path, 'r')
        vector_file = open(vector_file_path, 'r')

        for word, vec_str in zip(word_file, vector_file):
            word = word.strip()
            word = self.clean_word(word)
            vec_str = vec_str.strip()

            self.LSA_DICT[word] = self.trans_vec_string(vec_str)


        print("lsa model constructed")

    def clean_word(self, word):
        """
        preprocess word for future use
        """
        cleaned_word = word.strip()
        cleaned_word = cleaned_word.replace('\xef\xbb\xbf', '')
        cleaned_word = cleaned_word.replace('\ufeff', '')
        return cleaned_word

    def trans_vec_string(self, vec_str):
        """
        convert a string containing vectorization information, to a list of value for each coordinate
        """
        float_vec = []
        for coord in vec_str.split():
            float_vec.append(float(coord))
        return float_vec



    def get_valid_flow(self, answer_list, flow_list, fill_zero=False):
        """
        get only the valid forward flow

        if a flow value is nan, it depends on the "fill_zero" argument:
            1. fill_zero = False: we remove this flow value, also remove the answer associated with it
            2. fill_zero = True : we change the flow value to 0, keep this record
        """

        valid_answer_list = []
        valid_flow_list = []
        for idx, flow in enumerate(flow_list):
            if flow:
                valid_answer_list.append(answer_list[idx])
                valid_flow_list.append(flow)
            elif fill_zero:
                valid_answer_list.append(answer_list[idx])
                valid_flow_list.append(0)
        return valid_answer_list, valid_flow_list



    def get_forward_flow(self, seed_word, answer_list):
        """
        get forward flow of a answer list
        input:    seed_word   -> seed word or the hint provided to the user
                  answer_list -> a list of answers user provide
        output:   seed_word   -> same as before
                  answer_list -> same as input
                  flow_list   -> flow value assigned to each of answer in the answer list
        """

        flow_list = []
        answer_list = [self.remove_symbols(x) for x in answer_list]

        '''
        auto correction: make correction so that the LSA dictionary can understand the answer
        use_correction_file == 1: use a existing correction file to do the matching
        use_correction_file == 0: use the automated program to make correction
        '''
        if self.CONFIG["make_correction"] == 1:
            if self.CONFIG["use_correction_file"] == 1:
                answer_list = [self.corrector.auto_correct_by_file(answer, self.LSA_DICT) for answer in answer_list]
            else:
                answer_list = [self.corrector.auto_correct(answer, self.LSA_DICT) for answer in answer_list]

        # calculate a flow for each answere
        for idx, answer in enumerate(answer_list):
            flow = self.calculate_flow(answer, answer_list[:idx])
            flow_list.append(flow)
        return seed_word, answer_list, flow_list

    def calculate_flow(self, answer, answer_list):
        """
        calculate the flow of a answer list based on seed word
        input: an answer and its preceding answers
        output: a forward flow score for this answer, based on the paper
        """

        past_total = 0
        flow_count = 0
        vec1 = self.vectorize(answer)

        for past_answer in answer_list:
            vec2 = self.vectorize(past_answer)

            try:
                flow = cosine(vec1, vec2)
            except Exception as error:
                flow = None

            if flow:
                past_total += flow
                flow_count += 1

        if flow_count != 0:
            return past_total/flow_count
        return None

    def vectorize(self, sentence):
        """
        vectorize a sentence
        """
        bag_of_words = sentence.lower().split()
        # bag_of_words = bag_of_words[:2]

        unknown_count = 0
        word_count = len(bag_of_words)
        avg_vec = None

        # we can implement a weight here
        for word in bag_of_words:
            _vec = self.vectorize_single_word(word)
            try:
                avg_vec = [x+y for x, y in zip(avg_vec, _vec)]
            except TypeError:
                if not avg_vec:
                    avg_vec = _vec
                if not _vec:
                    unknown_count += 1

        word_count -= unknown_count
        try:
            avg_vec = [x/word_count for x in avg_vec]
        except TypeError:
            avg_vec = None

        return avg_vec

    def vectorize_single_word(self, word):
        """
        convert a single word to a vector
        """
        try:
            vec = self.LSA_DICT[word]
        except KeyError:
            return None
        except IndexError:
            return None
        return vec

    def output_correction_dict(self):
        '''
        generate the correction list
        '''
        self.corrector.output_correction_dict()



    def get_question_avg_flow(self, _df, starting_index):
        """
        for each question, get the average score
        (provide score column-wise)
        """

        average_flow = []
        for i in range(starting_index, _df.shape[1]):
            column_values = [x for x in _df.iloc[:, i].values.tolist() if ~np.isnan(x)]
            column_values = [x for x in column_values if x != 0]
            if len(column_values) == 0:
                average_flow.append(0)
            else:
                average_flow.append(mean(column_values))
        return average_flow

    def get_idea_column_names(self, CONFIG):
        """
        get idea column names
        """
        return [CONFIG["column_name"]+str(idx) for idx in range(1, CONFIG["questions_in_the_study"]+1)]



    def remove_symbols(self, answer):
        '''
        remove the non character symbols from the answers
        '''
        return ' '.join(re.sub("[^\w]", " ", answer).split())

    def remove_common_words(self, answer):
        '''
        remove commonly appeared word from the answer
        '''
        answer = self.remove_symbols(answer)
        try:
            for term in self.common_word_list:
                answer = ' '.join(re.sub(" "+term+" ", " ", answer.lower()).split())
        except Exception as e:
            print(e)
        return answer
