#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(broom)
library(MASS)
library(purrr)

#move data folder to desktop
setwd("~/Desktop/Data")

liwc_gen = read.csv("LIWC_data.csv")

#######################################################
# reshape and clean: Generation                       #
#######################################################

liwc_gen_clean = liwc_gen %>% 
  dplyr::select(-OtherP, -Parenth, -Apostro, -Quote, -Dash, -Exclam, -SemiC, -Colon, -Comma, -Period, -AllPunc, -filler, -WPS, -text)

#removing items that are irrelevant becuase this is spoken (e.g. "comma").

coefficient_gen = liwc_gen_clean %>% 
  gather(key, value, -Group.Number, - participant, -cond) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ lmer(value ~ cond + (1|Group.Number), data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  filter(term=="condvideo") %>%
  mutate(p.value = round(p.value,3)) %>%
  dplyr::select(-data, -fit, -effect, - group, -term)

table_mean = liwc_gen_clean %>%
  gather(key, value, -Group.Number, - participant, -cond) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm =T)) %>%
  mutate(mean = round(mean, 2)) %>%
  spread(cond, mean) %>%
  rename(virtual_mean = video,
         inperson_mean = f2f)

table_sd = liwc_gen_clean %>%
  gather(key, value, -Group.Number, - participant, -cond) %>%
  group_by(key, cond) %>%
  summarise(sd = sd(value, na.rm=T)) %>%
  mutate(sd = round(sd, 2)) %>%
  spread(cond, sd) %>%
rename(virtual_sd = video,
       inperson_sd = f2f)

table = merge(table_mean, table_sd, by = "key")

summary_gen = merge(table, coefficient_gen, by="key")

summary_gen$estimate = round(summary_gen$estimate,2)
summary_gen$std.error = round(summary_gen$std.error,2)
summary_gen$statistic = round(summary_gen$statistic,2)
summary_gen$p.value = round(summary_gen$p.value,3)

#######################################################
# LIWC predicting generation                          #
#######################################################

d.gen1 = read.csv("study1_data.csv")
d.gen2 = read.csv("study2_data.csv")

d.gen1 = d.gen1 %>% dplyr::select(Group.Number, creative_count)
d.gen2 = d.gen2 %>% dplyr::select(Group.Number, creative_count)
d.gen2$Group.Number = paste0(d.gen2$Group.Number, "study2")

d.gen = rbind(d.gen1, d.gen2)

liwc_gen_mean = liwc_gen_clean %>% 
  dplyr::select(-participant) %>%
  group_by(Group.Number,cond) %>%
  summarise_each(funs(mean(., na.rm = TRUE))) %>%
  ungroup()

d.gen = merge(d.gen, liwc_gen_mean, by = c("Group.Number"))

#write.csv(d.gen, "liwc_generation_mean.csv")

coefficient_predict_creative = d.gen %>% 
  gather(key, value, -Group.Number, -cond, -creative_count) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ glm.nb(creative_count ~ value, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  filter(term=="value") %>%
  mutate(p.value = round(p.value,3))%>%
  dplyr::select(-data, -fit, -term)

#######################################################
# Results                                             #
#######################################################

#write.csv(coefficient_predict_creative, "both_table_liwc_predict_generation.csv")
#write.csv(summary_gen, "both_table_modality_predict_gen_liwc.csv")

#######################################################
# Significant Regressions                             #
#######################################################

summary(lmer(you ~ cond + (1|Group.Number), data = liwc_gen))

#######################################################
# Effect of Condition when controlling for diffs      #
#######################################################

summary(glm.nb(creative_count ~ cond + you + sad, data = d.gen))

#######################################################
# Efect Sizes for Significant Differences             #
#######################################################

d.gen$cond = as.factor(d.gen$cond)
cohen.d(d.gen$WC, d.gen$cond)
cohen.d(d.gen$you, d.gen$cond)

#######################################################
# Making Table                                        #
#######################################################

summary_gen = summary_gen %>% dplyr::select(key, virtual_mean, virtual_sd, inperson_mean, inperson_sd, estimate, std.error, statistic, p.value)
table = merge(summary_gen, coefficient_predict_creative, by = "key")

#write.csv(table, "LIWC_summary_table.csv")

#######################################################
# Levene's Test                                       #
#######################################################

l_test = liwc_gen_clean %>% 
  gather(key, value, -Group.Number, - participant, -cond) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ leveneTest(value ~ cond, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  mutate(p.value = round(p.value,3)) %>%
  dplyr::select(-data, -fit)

kruskal.test(liwc_gen_mean$WC ~ liwc_gen_mean$cond)
kruskal.test(liwc_gen_mean$sad ~ liwc_gen_mean$cond)
kruskal.test(liwc_gen_mean$quant ~ liwc_gen_mean$cond)
kruskal.test(liwc_gen_mean$see ~ liwc_gen_mean$cond)
kruskal.test(liwc_gen_mean$netspeak ~ liwc_gen_mean$cond)

