#########################################################
# load libraries, set working directory, read in data   #
#########################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(broom)
library(broom.mixed)
library(MASS)
library(purrr)

#move data folder to desktop
setwd("~/Desktop/Data")

d = read.csv("sound_video_codes.csv")

#######################################################
# differences by condition                            #
#######################################################

rs = lmer(d[,5] ~ cond + (1|Group.Number) + (1|video) + (1|id), data=d)
results = broom::tidy(rs)
results$key = rep(names(d[2]))

for(i in 5:23){
  rs = lmer(d[,i] ~ cond + (1|Group.Number) + (1|video) + (1|id), data =d)
  stats = broom::tidy(rs)
  stats$key = rep(names(d[i]))
  results = rbind(results, stats)
}

results = results %>% filter(term=="condvideo") %>%
  dplyr::select(-group, -effect, -term)

table_mean = d %>% 
  gather(key, value, -video, -id, -cond, -Group.Number) %>%
  group_by(key, cond) %>%
  summarise(mean = mean(value, na.rm =T)) %>%
  mutate(mean = round(mean, 2)) %>%
  spread(cond, mean) %>%
  rename(virtual_mean = video,
         inperson_mean = f2f)

table_sd = d %>% 
  gather(key, value, -video, -id, -cond, -Group.Number) %>%
  group_by(key, cond) %>%
  summarise(sd = sd(value, na.rm =T)) %>%
  mutate(sd = round(sd, 2)) %>%
  spread(cond, sd) %>%
  rename(virtual_sd = video,
         inperson_sd = f2f)

table = merge(table_mean, table_sd, by = "key")

results = results %>% filter(key!="video")
summary_sound = merge(table, results, by="key")

summary_sound$estimate = round(summary_sound$estimate,2)
summary_sound$std.error = round(summary_sound$std.error,2)
summary_sound$statistic = round(summary_sound$statistic,2)
summary_sound$p.value = round(summary_sound$p.value,3)

#######################################################
# predicting creativity                               #
#######################################################

d.gen = read.csv("study2_data.csv")
d.gen = d.gen %>% dplyr::select(Group.Number, creative_count)

sound_mean = d %>% dplyr::select(-id) %>%
  group_by(Group.Number, cond, video) %>%
  summarise_each(funs(mean(., na.rm = TRUE))) %>%
  dplyr::select(-video) %>%
  group_by(Group.Number, cond) %>%
  summarise_each(funs(mean(., na.rm = TRUE)))
    
d.gen = merge(d.gen, sound_mean, by = c("Group.Number"))

coefficient_predict_creative = d.gen %>% 
  gather(key, value, -Group.Number, -cond, -creative_count) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ glm.nb(creative_count ~ value, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  filter(term=="value") %>%
  mutate(p.value = round(p.value,3))

#######################################################
# Results                                             #
#######################################################

#write.csv(summary_sound, "table_cond_predict_sound_videos.csv")
#write.csv(coefficient_predict_creative, "table_sound_videos_predict_generation.csv")

#######################################################
# Significant Regressions                             #
#######################################################

summary(lmer(dominant_sound ~ cond + (1|Group.Number) + (1|video) + (1|id),  data = d))
summary(lmer(comf_sound ~ cond + (1|Group.Number) + (1|video) + (1|id),  data = d))
summary(lmer(confident_sound ~ cond + (1|Group.Number) + (1|video) + (1|id),  data = d))
summary(lmer(self_conscious_sound ~ cond + (1|Group.Number) + (1|video) + (1|id),  data = d))

#######################################################
# Effect of Condition when controlling for diffs      #
#######################################################

summary(glm.nb(creative_count ~ cond + dominant_sound, data = d.gen))
summary(glm.nb(creative_count ~ cond + comf_sound, data = d.gen))
summary(glm.nb(creative_count ~ cond + confident_sound, data = d.gen))
summary(glm.nb(creative_count ~ cond + self_conscious_sound, data = d.gen))

summary(glm.nb(creative_count ~ cond + self_conscious_sound + dominant_sound + comf_sound + confident_sound, data = d.gen))

#######################################################
# Efect Sizes for Significant Differences             #
#######################################################

d$cond = as.factor(d$cond)
cohen.d(d$dominant_sound, d$cond)
cohen.d(d$comf_sound, d$cond)
cohen.d(d$confident_sound, d$cond)
cohen.d(d$self_conscious_sound, d$cond)

#######################################################
# Levene's Test                                       #
#######################################################

l_test = d %>% 
  gather(key, value, -Group.Number, - video, -id, -cond) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ leveneTest(value ~ cond, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  mutate(p.value = round(p.value,3)) %>%
  dplyr::select(-data, -fit)

kruskal.test(d.gen$work_tog_sound ~ d.gen$cond)
