#################################################
# load libraries, read in data                  #
#################################################
rm(list=ls())
library(dplyr)
library(psych)
library(tidyr)
library(lme4)
library(lmerTest)
library(broom.mixed)
library(broom)
library(purrr)
library(MASS)
library(car)
options(scipen=999)

#move data folder to desktop
setwd("~/Desktop/Data")

survey_byp = read.csv("virtual_study_survey_byp.csv")

#######################################################
# Demographic Information                             #
#######################################################

summary(survey_byp$sex)
table(survey_byp$sex)
mean(survey_byp$age, na.rm=T)
sd(survey_byp$age, na.rm=T)

#######################################################
# Cleaning                                            #
#######################################################

survey_byp = survey_byp %>% dplyr::select(-major, -sex, -native, -school, -age, -Group.Size, -session) %>%
  mutate(Group.Size = as.factor(cond)) %>%
  dplyr::select(-cond)

#######################################################
# differences by condition                            #
#######################################################

survey2 = survey_byp %>% 
  gather(key, value, -Group.Number, -Group.Size) %>%
  filter(!is.na(value))

rs = lmer(survey_byp[,4] ~ Group.Size  +(1|Group.Number), data=survey_byp)
results = broom::tidy(rs)
results$key = rep(names(survey_byp[2]))

for(i in 2:19){
  rs = lmer(survey_byp[,i] ~ Group.Size +(1|Group.Number), data =survey_byp)
  stats = broom::tidy(rs)
  stats$key = rep(names(survey_byp[i]))
  results = rbind(results, stats)
}

results = results %>% filter(term=="Group.Size4" & key!="cond") %>%
  dplyr::select(-group, -effect, -term)

survey2$Group.Size <- factor(survey2$Group.Size, levels = c("4", "2"))
table_mean = survey2 %>% 
  dplyr::select(-Group.Number) %>%
  group_by(key, Group.Size) %>%
  summarise_each(funs(mean(., na.rm = TRUE))) %>%
  mutate(value = round(value, 2)) %>%
  spread(Group.Size, value) %>%
  rename(mean_2 = `2`,
         mean_4 = `4`)

table_sd = survey2 %>% 
  dplyr::select(-Group.Number) %>%
  group_by(key, Group.Size) %>%
  summarise_each(funs(sd(., na.rm = TRUE))) %>%
  mutate(value = round(value, 2)) %>%
  spread(Group.Size, value) %>%
  rename(SD_2 = `2`,
         SD_4 = `4`)

table = merge(table_mean, table_sd, by="key")

summary_survey = merge(table, results, by="key", all=T)

summary_survey = summary_survey %>% 
  dplyr::select(key, mean_2, SD_2, mean_4, SD_4, estimate, std.error, df, statistic, p.value)

#######################################################
# predicting creativity                               #
#######################################################

survey_mean = survey_byp %>%
  group_by(Group.Number, Group.Size) %>%
  summarise_each(funs(mean(., na.rm = TRUE)))

d.gen = read.csv("virtual_study_data.csv")
d.gen = d.gen %>% dplyr::select(Group.Number, creative_per_person)

d.gen = merge(d.gen, survey_mean, by = c("Group.Number"))

coefficient_predict_creative = d.gen %>% 
  gather(key, value, -Group.Number, -Group.Size, -creative_per_person) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ glm.nb(creative_per_person ~ value, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  filter(term=="value") %>%
  mutate(p.value = round(p.value,3))%>%
  dplyr::select(-data, -fit, -term)


#######################################################
# Results                                             #
#######################################################

rm(results, rs, stats, table, table_mean, table_sd, survey_mean)

#NOTE: check out coefficient_predict_creative and summary_survey for results

#######################################################
# Extra Regressions                                   #
#######################################################

#evaluation apprehension, controlling for dispositional anxiety
summary(lmer(crit_mean ~ Group.Size + IAS_mean + (1|Group.Number), data = survey_byp))

summary(lmer(block_mean ~ Group.Size + (1|Group.Number), data = survey_byp))

#######################################################
# Effect Sizes                                        #
#######################################################
cohen.d(survey_byp$crit_mean, survey_byp$Group.Size)
cohen.d(survey_byp$eval_mean, survey_byp$Group.Size)
cohen.d(survey_byp$loaf_mean, survey_byp$Group.Size)
cohen.d(survey_byp$block_mean, survey_byp$Group.Size)
cohen.d(survey_byp$coord_mean, survey_byp$Group.Size)

#######################################################
# Levene's.                                           #
#######################################################

l_test = survey_byp %>% 
  gather(key, value, -Group.Number, -Group.Size) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ leveneTest(value ~ Group.Size, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  mutate(p.value = round(p.value,3)) %>%
  dplyr::select(-data, -fit)

#######################################################
# Normality                                           #
#######################################################

survey_byp_norm = survey_byp %>% dplyr::select(-Group.Size)
rs = shapiro.test(survey_byp[,4])
n_test = broom::tidy(rs)
n_test$key = rep(names(survey_byp[2]))

for(i in 2:18){
  rs = shapiro.test(survey_byp[,i])
  stats = broom::tidy(rs)
  stats$key = rep(names(survey_byp[i]))
  n_test = rbind(n_test, stats)
}

#######################################################
# Kruskal Wallis                                      #
#######################################################

kw_test = d.gen %>% 
  gather(key, value, -Group.Number, -Group.Size) %>%
  nest(data = -key) %>%
  mutate(
    fit = map(data, ~ kruskal.test(value ~ Group.Size, data = .x)), # S3 list-col
    tidied = map(fit, tidy)
  ) %>% 
  unnest(tidied) %>%
  mutate(p.value = round(p.value,3)) %>%
  dplyr::select(-data, -fit)

write.csv(kw_test, "kruskal_wallis_results.csv")

